@@ -3,15 +3,13 @@
 # groffer - display groff files
 
 # Source file position: <groff-source>/contrib/groffer/groffer.sh
-# Installed position: <prefix>/bin/groffer
 
-# Copyright (C) 2001,2002,2003,2004,2005,2006
+# Copyright (C) 2001,2002,2003,2004,2005
 # Free Software Foundation, Inc.
 # Written by Bernd Warken
 
-# Last update: 3 Oct 2006
-
-# This file is part of `groffer', which is part of `groff'.
+# This file is part of `groffer', which is part of `groff' version
+# @VERSION@.  See $_GROFF_VERSION.
 
 # `groff' is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
@@ -31,6 +29,12 @@
 
 ########################################################################
 
+_PROGRAM_VERSION='0.9.22';
+_LAST_UPDATE='22 August 2005';
+
+export _PROGRAM_VERSION;
+export _LAST_UPDATE;
+
 export GROFFER_OPT;		# option environment for groffer
 
 export _CONF_FILE_ETC;		# configuration file in /etc
@@ -57,84 +61,36 @@ _ERROR='7';			# for syntax errors; no `-1' in `ash'
 
 # @...@ constructs
 
-export _BEFORE_MAKE;
+export _GROFF_VERSION
+_GROFF_VERSION='@VERSION@';
 if test _@VERSION@_ = _${_AT}VERSION${_AT}_
 then
-  # script before `make'
-  _BEFORE_MAKE='yes';
-else
-  _BEFORE_MAKE='no';
+  _GROFF_VERSION='1.19.2';
 fi;
 
 export _AT_BINDIR_AT;
 export _AT_G_AT;
 export _AT_LIBDIR_AT;
 export _GROFFER_LIBDIR;
-case "${_BEFORE_MAKE}" in
-yes)
-  self="$0";
-  case "${self}" in
-  /*) :; ;;
-  *)
-    curdir="$(pwd)";
-    case "${curdir}" in
-    */)
-      self="${curdir}${self}";
-      ;;
-    *)
-      self="${curdir}/${self}";
-      ;;
-    esac;
-    ;;
-  esac;
-  groffer_shell_dir="$(dirname ${self})";
-  case "${groffer_shell_dir}" in
-  */) :; ;;
-  *) groffer_shell_dir="${groffer_shell_dir}/";
-  esac;
-  _AT_G_AT='';
-  _AT_BINDIR_AT="${groffer_shell_dir}";
-  _AT_LIBDIR_AT="${groffer_shell_dir}";
-  _GROFFER_LIBDIR="${_AT_LIBDIR_AT}";
-  ;;
-no)
-  _AT_G_AT='@g@';
-  _AT_BINDIR_AT='@BINDIR@';
-  case "${_AT_BINDIR_AT}" in
-  */) :; ;;
-  *) _AT_BINDIR_AT="${_AT_BINDIR_AT}/";
-  esac;
-  _AT_LIBDIR_AT='@libdir@';
-  case "${_AT_LIBDIR_AT}" in
-  */) :; ;;
-  *) _AT_LIBDIR_AT="${_AT_LIBDIR_AT}/";
-  esac;
-  _GROFFER_LIBDIR="${_AT_LIBDIR_AT}"'groff/groffer/';
-  ;;
-esac;
-
-if test -f "${_GROFFER_LIBDIR}"'version.sh'
+if test _@BINDIR@_ = _${_AT}BINDIR${_AT}_
 then
-  . "${_GROFFER_LIBDIR}"'version.sh';
+  # script before `make'
+  _AT_BINDIR_AT='.';
+  _AT_G_AT='';
+  _AT_LIBDIR_AT='';
+  _GROFFER_LIBDIR='.';
+else
+  _AT_BINDIR_AT='@BINDIR@';
+  _AT_G_AT='@g@';
+  _AT_LIBDIR_AT='@libdir@';
+  _GROFFER_LIBDIR="${_AT_LIBDIR_AT}"'/groff/groffer';
 fi;
 
-export _GROFF_VERSION;
-case "${_BEFORE_MAKE}" in
-yes)
-  _GROFF_VERSION="${_GROFF_VERSION_PRESET}";
-  ;;
-no)
-  _GROFF_VERSION='@VERSION@';
-  ;;
-esac;
-
-export _GROFFER2_SH;		# file name of the script that follows up
-_GROFFER2_SH="${_GROFFER_LIBDIR}"'groffer2.sh';
-
 export _GROFFER_SH;		# file name of this shell script
 case "$0" in
 *groffer*)
   _GROFFER_SH="$0";
+  # was: _GROFFER_SH="${_AT_BINDIR_AT}/groffer";
   ;;
 *)
   echo 'The groffer script should be started directly.' >&2
@@ -142,6 +98,9 @@ case "$0" in
   ;;
 esac;
 
+export _GROFFER2_SH;		# file name of the script that follows up
+_GROFFER2_SH="${_GROFFER_LIBDIR}"/groffer2.sh;
+
 export _NULL_DEV;
 if test -c /dev/null
 then
@@ -182,22 +141,21 @@ do
 # Delete leading and final space
 s/^['"${_SP}${_TAB}"']*//
 s/['"${_SP}${_TAB}"']*$//
-# Print all lines with shell commands, those not starting with -
+# Print all shell commands
 /^[^-]/p
-# Remove all single and double quotes
-s/['"${_SQ}"'"]//g
 # Replace empty arguments
 s/^\(-[^ ]*\)=$/o="${o} \1 '"${_SQ}${_SQ}"'"/p
 # Replace division between option and argument by single space
 s/[='"${_SP}${_TAB}"']['"${_SP}${_TAB}"']*/'"${_SP}"'/
 # Handle lines without spaces
 s/^\(-[^'"${_SP}"']*\)$/o="${o} \1"/p
+# Print options that have their argument encircled with single quotes
+/^-[^ ]* '"${_SQ}"'.*'"${_SQ}"'$/s/^.*$/o="${o} &"/p
+# Replace encircled double quotes by single quotes and print the result
+s/^\(-[^ ]*\) "\(.*\)"$/o="${o} \1 '"${_SQ}"'\2'"${_SQ}"'"/p
 # Encircle the remaining arguments with single quotes
 s/^\(-[^ ]*\) \(.*\)$/o="${o} \1 '"${_SQ}"'\2'"${_SQ}"'"/p
 ')"
-
-    # Remove leading space
-    o="$(echo "$o" | sed -e 's/^ *//')";
     if test _"${o}"_ != __
     then
       if test _"{GROFFER_OPT}"_ = __
@@ -230,7 +188,7 @@ _SHELL=`
   # $s means shell.
   # The command line arguments are taken over.
   # Shifting herein does not have an effect outside.
-  export x;
+  export x;  
   case " $*" in
   *\ --sh*)			# abbreviation for --shell
     x='';
@@ -331,7 +289,7 @@ fi;
 if test _"${_SHELL}"_ = __
 then
   # no shell found, so start groffer2.sh normally
-  eval . "'${_GROFFER2_SH}'" '"$@"';
+  eval exec "'${_GROFFER2_SH}'" '"$@"';
   exit;
 else
   # start groffer2.sh with the found $_SHELL
